@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::Depak;
 
 our $DATE = '2015-07-06'; # DATE
-our $VERSION = '0.10'; # VERSION
+our $VERSION = '0.11'; # VERSION
 
 use 5.010001;
 use strict;
@@ -115,7 +115,9 @@ sub munge_script {
     $self->log_debug(["depak output: %s (%s, %d bytes)",
                       $file->{name}, $target, length($content)]);
 
-    for (@{ $depak_res->[3]{'function.included_modules'} }) {
+    #$self->log_debug(["depak result: %s", $depak_res]);
+
+    for (@{ $depak_res->[3]{'func.included_modules'} }) {
         $self->{_mods}{$_} = 0;
     }
 
@@ -158,6 +160,7 @@ sub munge_module {
     }
 
     if ($munged) {
+        $self->log_debug(["Setting \@PACKED_MODULES / \@PACKED_DISTS in %s", $file->{name}]);
         $file->content($content);
     }
 }
@@ -180,7 +183,7 @@ Dist::Zilla::Plugin::Depak - Pack dependencies onto scripts during build using '
 
 =head1 VERSION
 
-This document describes version 0.10 of Dist::Zilla::Plugin::Depak (from Perl distribution Dist-Zilla-Plugin-Depak), released on 2015-07-06.
+This document describes version 0.11 of Dist::Zilla::Plugin::Depak (from Perl distribution Dist-Zilla-Plugin-Depak), released on 2015-07-06.
 
 =head1 SYNOPSIS
 
